
/*
 *<SOURCE_HEADER>
 *
 *  <NAME>
 *    approx.h
 *  </NAME>
 *  <AUTHOR>
 *    Anthony R. Cassandra
 *  </AUTHOR>
 *  <CREATE_DATE>
 *    
 *  </CREATE_DATE>
 *
 *  <RCS_KEYWORD>
 *    $RCSfile: approx.h,v $
 *    $Source: /u/cvs/proj/pomdp-solve/src/approx.h,v $
 *    $Revision: 1.1 $
 *    $Date: 2003/05/13 21:46:39 $
 *  </RCS_KEYWORD>
 *
 *  <COPYRIGHT>
 *
 *    1994-1997, Brown University
 *    1998-2003, Anthony R. Cassandra
 *
 *    All Rights Reserved
 *                          
 *    Permission to use, copy, modify, and distribute this software and its
 *    documentation for any purpose other than its incorporation into a
 *    commercial product is hereby granted without fee, provided that the
 *    above copyright notice appear in all copies and that both that
 *    copyright notice and this permission notice appear in supporting
 *    documentation.
 * 
 *    ANTHONY CASSANDRA DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
 *    INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
 *    PARTICULAR PURPOSE.  IN NO EVENT SHALL ANTHONY CASSANDRA BE LIABLE FOR
 *    ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *    WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 *    ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 *    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 *  </COPYRIGHT>
 *
 *</SOURCE_HEADER>
 */

/*
 *   Header file for all the approximation source code files.
 */

#ifndef APPROX_H
#define APPROX_H

/*******************************************************************/
/**************      USEFUL MNENOMIC CONSTANTS      ****************/
/*******************************************************************/

/* Command line options for Monte Carlo Gauss Seidel */
#define CMD_ARG_MCGS_TRAJECTORY_LENGTH            "-traj_length"
#define CMD_ARG_MCGS_NUM_TRAJECTORIES             "-num_traj"
#define CMD_ARG_MCGS_TRAJECTORY_ITERATE_COUNT     "-traj_iter_count"
#define CMD_ARG_MCGS_PRUNE_FREQUENCY              "-prune_freq"

/*******************************************************************/
/**************         DEFAULT VALUES              ****************/
/*******************************************************************/

#define DEFAULT_MCGS_TRAJ_LENGTH                  100
#define DEFAULT_MCGS_NUM_TRAJ                    1000
#define DEFAULT_MCGS_TRAJ_ITER                      1
#define DEFAULT_MCGS_PRUNE_FREQ                   100

/*******************************************************************/
/**************             TYPEDEFS                ****************/
/*******************************************************************/

typedef struct ApproxParamStruct *ApproxParams;
struct ApproxParamStruct {

    /****************************************************/
   /***** For the Monte Carlo Gauss Seidel version *****/
  /****************************************************/

  /* How long are the trajectories which will serves as the source of
     belief points. */
  int mcgs_trajectory_length;

  /* How many trajectories to generate before being finished. */
  int mcgs_num_trajectories;

  /* For each trajectory generated, how many times to iterate of the
     belief points in the trajectory before generating a new
     trajectory. */
  int mcgs_trajectory_iterate_count;
  
  /* The defines how often we will update the value funciton.  It is
     measured in terms of number of new vectors generated. */
  int mcgs_prune_frequency;

};

#endif

